package com.steerinfo.dil.controller;

import com.steerinfo.dil.service.impl.BmstrainDetailsOrderServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/14 9:26
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/bmstraindetailsorders")
public class BmstrainDetailsOrderController extends BaseRESTfulController {

    @Autowired
    BmstrainDetailsOrderServiceImpl bmstrainDetailsOrderService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    /**
     * 展示火运详单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示火运详单列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "118", required = false, dataType = "Integer")
    })
    @PostMapping("/getTrainDetailsOrderList")
    public RESTfulResult getTrainDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  Integer apiId) {
        List<Map<String, Object>> list = bmstrainDetailsOrderService.getTrainDetailsOrderList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainDetailsOrderService.getTrainDetailsOrderList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     * 展示未转账单的火运详单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示未转账单的火运详单列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "118", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getUncomplateTrainDetailsList")
    public RESTfulResult getUncomplateTrainDetailsList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                       Integer pageNum,
                                                       Integer pageSize,
                                                       Integer apiId) {
        List<Map<String, Object>> list = bmstrainDetailsOrderService.getUmcomplateTrainDetailsList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainDetailsOrderService.getUmcomplateTrainDetailsList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     * 展示火运实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示火运实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "122", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTrainResultList")
    public RESTfulResult getTrainResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer apiId) {
        List<Map<String, Object>> list = bmstrainDetailsOrderService.getTrainResultList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainDetailsOrderService.getTrainResultList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     * 生成火运详单
     *
     * @param map
     * @return
     */
    @ApiModelProperty(value = "生成火运详单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "火运实绩", required = false, dataType = "java.util.List"),
    })
    @PostMapping("/addTrainDetails")
    public RESTfulResult addTrainDetails(@RequestBody Map<String, Object> map) {
        int code = bmstrainDetailsOrderService.insertSelective(map);
        return success(code);
    }
}
