package com.steerinfo.dil.controller;

import com.steerinfo.dil.model.BmstrainSettlement;
import com.steerinfo.dil.service.impl.BmstrainSettlementServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/10/18 11:53
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/bmstrainsettlement")
public class BmstrainSettlementController extends BaseRESTfulController {
    @Autowired
    BmstrainSettlementServiceImpl bmstrainSettlementService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    /**
     * 展示火运结算列表
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示火运结算列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "180", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getSettlementList")
    public RESTfulResult getSettlementList(@RequestBody(required = false) Map<String,Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        List<Map<String, Object>> list = bmstrainSettlementService.getSettlementList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainSettlementService.getSettlementList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }


    /**
     * 新增火运结算
     * @param bmstrainSettlement
     * @return
     */
    @ApiModelProperty(value = "新增火运结算")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "bmstrainSettlement", value = "火运结算实体", required = false, dataType = "BmstrainSettlement"),
    })
    @PostMapping("/addTrainSettlement")
    public RESTfulResult addTrainSettlement(@RequestBody BmstrainSettlement bmstrainSettlement) {
        int result = bmstrainSettlementService.addTrainSettlement(bmstrainSettlement);
        return success(result);
    }

    /**
     * 逻辑删除火运结算
     * @param settlementId
     * @return
     */
    @ApiModelProperty(value = "逻辑删除火运结算")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "settlementId", value = "结算id", required = false, dataType = "BigDecimal"),
    })
    @PostMapping("/deleteTrainSettlement/{settlementId}")
    public RESTfulResult deleteTrainSettlement(@PathVariable("settlementId") BigDecimal settlementId) {
        int result = bmstrainSettlementService.deleteTrainSettlement(settlementId);
        return success(result);
    }

    /**
     * 修改火运结算
     * @param bmstrainSettlement
     * @return
     */
    @ApiModelProperty(value = "修改火运结算")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "bmstrainSettlement", value = "火运结算实体", required = false, dataType = "BmstrainSettlement"),
    })
    @PostMapping("/updateTrainSettlement")
    public RESTfulResult updateTrainSettlement(@RequestBody BmstrainSettlement bmstrainSettlement) {
        int result = bmstrainSettlementService.updateTrainSettlement(bmstrainSettlement);
        return success(result);
    }

    /**
     * 得到修改渲染
     * @param settlementId
     * @return
     */
    @ApiModelProperty(value = "得到修改渲染")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "settlementId", value = "结算id", required = false, dataType = "BigDecimal"),
    })
    @PostMapping("/selectTrainSettlement/{settlementId}")
    public RESTfulResult selectTrainSettlement(@PathVariable("settlementId") BigDecimal settlementId) {
        BmstrainSettlement bmstrainSettlement = bmstrainSettlementService.selectTrainSettlement(settlementId);
        return success(bmstrainSettlement);
    }


}
