package com.steerinfo.dil.controller;

import com.steerinfo.dil.service.impl.BmstrainDetailsOrderServiceImpl;
import com.steerinfo.dil.service.impl.BmstrainStatementServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/14 9:26
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/bmstrainstatement")
public class BmstrainStatementController extends BaseRESTfulController {

    @Autowired
    BmstrainStatementServiceImpl bmstrainStatementService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    /**
     * 展示火运账单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示火运账单列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "121", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTrainStatementList")
    public RESTfulResult getTrainStatementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId) {
        List<Map<String, Object>> list = bmstrainStatementService.getTrainStatementList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainStatementService.getTrainStatementList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     * 生成火运费账单
     *
     * @param mapList
     * @return
     */
    @ApiModelProperty(value = "生成火运费账单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapList", value = "详单列表", required = false, dataType = "java.util.List"),
    })
    @PostMapping("/addTrainStatement")
    public RESTfulResult addTrainStatement(@RequestBody List<Map<String, Object>> mapList) {
        int code1 = bmstrainStatementService.insertSelective(mapList);
        return success(code1);
    }

    /**
     * 展示账单下的详单
     *
     * @param batchId
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @param statementId
     * @return
     */
    @ApiOperation(value = "展示账单下的详单", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "batchId", value = "批次id", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "118", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getComplateTrainDetailsList")
    public RESTfulResult getComplateTrainDetailsList(BigDecimal batchId,
                                                     @RequestBody(required = false) Map<String, Object> mapVal,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer apiId,
                                                     BigDecimal statementId) {
        if (mapVal == null) {
            mapVal = new HashMap<>();
        }
        mapVal.put("batchId", batchId);
        mapVal.put("statementId", statementId);
        List<Map<String, Object>> list = bmstrainStatementService.getComplateTrainDetailsList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainStatementService.getComplateTrainDetailsList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     * 展示火运实绩
     *
     * @param detailsId
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value = "展示火运实绩", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "detailsId", value = "详单id", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "122", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getStatementTrainResultList")
    public RESTfulResult getStatementTrainResultList(@RequestBody(required = false) Map<String, Object> mapVal,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer apiId,
                                                     Integer detailsId) {
        if (mapVal == null) {
            mapVal = new HashMap<>();
        }
        mapVal.put("detailsId", detailsId);
        List<Map<String, Object>> list = bmstrainStatementService.getTrainResultList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstrainStatementService.getTrainResultList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }
}
