package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.BmstrainDetailsOrderMapper;
import com.steerinfo.dil.model.BmstrainDetailsOrder;
import com.steerinfo.dil.service.IBmstrainDetailsOrderService;
import com.steerinfo.dil.util.NoUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/14 9:29
 * @Version:V2.0
 */
@Service
public class BmstrainDetailsOrderServiceImpl implements IBmstrainDetailsOrderService {

    @Autowired
    BmstrainDetailsOrderMapper bmstrainDetailsOrderMapper;
    @Autowired
    NoUtil noUtil;

    /**
     * 得到最大id
     * @return
     */
    @Override
    public BigDecimal selectMaxId() {
        return bmstrainDetailsOrderMapper.selectDetailsId();
    }

    /**
     * 得到采购订单id
     * @param purchaseOrderNo
     * @return
     */
    @Override
    public BigDecimal getPurchaseOrderId(String purchaseOrderNo) {
        return bmstrainDetailsOrderMapper.getPurchaseOrderId(purchaseOrderNo);
    }

    /**
     * 得到火运单价ID
     * @param trainType
     * @return
     */
    @Override
    public BigDecimal getTrainPriceId(String trainType) {
        return bmstrainDetailsOrderMapper.getTrainPriceId(trainType);
    }

    /**
     * 得到火运单价
     * @param trainType
     * @return
     */
    @Override
    public BigDecimal getTrainPrice(String trainType) {
        return bmstrainDetailsOrderMapper.getTrainPrice(trainType);
    }

    /**
     * 展示详单列表
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getTrainDetailsOrderList(Map<String, Object> mapValue) {
        return bmstrainDetailsOrderMapper.getTrainDetailsOrderList(mapValue);
    }

    /**
     * 展示详单列表
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getUmcomplateTrainDetailsList(Map<String, Object> mapValue) {
        return bmstrainDetailsOrderMapper.getUmcomplateTrainDetailsList(mapValue);
    }

    /**
     * 通过主键查询
     * @param detailsId
     * @return
     */
    @Override
    public BmstrainDetailsOrder selectByPrimaryKey(BigDecimal detailsId) {
        return bmstrainDetailsOrderMapper.selectByPrimaryKey(detailsId);
    }

    /**
     * 修改
     * @param bmstrainDetailsOrder
     * @return
     */
    @Override
    public int updateByPrimaryKeySelective(BmstrainDetailsOrder bmstrainDetailsOrder) {
        return bmstrainDetailsOrderMapper.updateByPrimaryKeySelective(bmstrainDetailsOrder);
    }

    /**
     * 展示火运实绩
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getTrainResultList(Map<String, Object> mapValue) {
        return bmstrainDetailsOrderMapper.getTrainResultList(mapValue);
    }

    /**
     * 新增详单
     * @param map
     * @return
     */
    @Override
    public int insertSelective(Map<String,Object> map) {
        BmstrainDetailsOrder bmstrainDetailsOrder = new BmstrainDetailsOrder();
        // 设置主键
        BigDecimal detailsId = selectMaxId();
        bmstrainDetailsOrder.setDetailsId(detailsId);
        // 设置详单号
        String detailsNo = noUtil.setResultNo("HYXD", detailsId);
        bmstrainDetailsOrder.setDetailsNo(detailsNo);
        // 设置详单时间
        bmstrainDetailsOrder.setDetailsTime(new Date());
        // 联系火运实绩
        BigDecimal trainLoadingResultId = new BigDecimal((Integer) map.get("trainLoadingResultId"));
        bmstrainDetailsOrder.setTrainLoadingResultId(trainLoadingResultId);
        // 设置详单状态
        bmstrainDetailsOrder.setWetherToStatement(new BigDecimal(0));
        // 设置详单采购订单id
        String purchaseOrderNo = (String) map.get("purchaseOrderNo");
        BigDecimal purchaseOrderId = getPurchaseOrderId(purchaseOrderNo);
        bmstrainDetailsOrder.setPurchaseOrderId(purchaseOrderId);
        // 设置火运单价
        String resultWagonNo = (String) map.get("resultWagonNo");
        String subStr2 = resultWagonNo.substring(0,2);
        String subStr3 = resultWagonNo.substring(0,3);
        if (subStr2.equals("45") || subStr2.equals("46") || subStr3.equals("140") || subStr3.equals("141") || subStr3.equals("142") || subStr3.equals("143")) {
            BigDecimal trainPriceId = getTrainPriceId("60车型");
            bmstrainDetailsOrder.setPriceId(trainPriceId);
            BigDecimal trainPrice = getTrainPrice("60车型");
            bmstrainDetailsOrder.setDetailsAmount(trainPrice);
            bmstrainDetailsOrder.setDetailsFloatAmount(new BigDecimal(trainPrice.doubleValue() * 0.8));
            bmstrainDetailsOrder.setDetailsMaginAmount(new BigDecimal(trainPrice.doubleValue() * 0.2));
        }
        if (subStr2.equals("42") || subStr2.equals("47") || subStr2.equals("48") || subStr2.equals("49") || subStr3.equals("145")) {
            BigDecimal trainPriceId = getTrainPriceId("61车型");
            bmstrainDetailsOrder.setPriceId(trainPriceId);
            BigDecimal trainPrice = getTrainPrice("61车型");
            bmstrainDetailsOrder.setDetailsAmount(trainPrice);
            bmstrainDetailsOrder.setDetailsFloatAmount(new BigDecimal(trainPrice.doubleValue() * 0.8));
            bmstrainDetailsOrder.setDetailsMaginAmount(new BigDecimal(trainPrice.doubleValue() * 0.2));
        }
        if (subStr2.equals("15") || subStr2.equals("16") || subStr2.equals("17") || subStr2.equals("18")) {
            BigDecimal trainPriceId = getTrainPriceId("70车型");
            bmstrainDetailsOrder.setPriceId(trainPriceId);
            BigDecimal trainPrice = getTrainPrice("70车型");
            bmstrainDetailsOrder.setDetailsAmount(trainPrice);
            bmstrainDetailsOrder.setDetailsFloatAmount(new BigDecimal(trainPrice.doubleValue() * 0.8));
            bmstrainDetailsOrder.setDetailsMaginAmount(new BigDecimal(trainPrice.doubleValue() * 0.2));
        }
        // 设置常规字段
        bmstrainDetailsOrder.setInsertTime(new Date());
        bmstrainDetailsOrder.setInsertUsername("admin");
        bmstrainDetailsOrder.setUpdateTime(new Date());
        bmstrainDetailsOrder.setUpdateUsername("admin");
        bmstrainDetailsOrder.setInsertUpdateRemark("无");
        return bmstrainDetailsOrderMapper.insertSelective(bmstrainDetailsOrder);
    }


}
